@@ -21,6 +21,10 @@
 #include "errors.h"
 #include "arggetter.h"
 
+#include <limits.h>
+#include <stdlib.h>
+#include <unistd.h>
+
 #define InternalEval aEnvironment.iEvaluator->Eval
 #define RESULT aEnvironment.iStack.GetElement(aStackTop)
 #define ARGUMENT(i) aEnvironment.iStack.GetElement(aStackTop+i)
@@ -790,6 +794,24 @@ void LispLoad(LispEnvironment& aEnvironment, LispInt aStackTop)
     InternalTrue(aEnvironment,RESULT);
 }
 
+void LispTmpFile(LispEnvironment& aEnvironment, LispInt aStackTop)
+{
+    CHK_CORE(aEnvironment.iSecure == 0, KLispErrSecurityBreach);
+
+    LispChar fn[] = "/tmp/yacas-XXXXXX";
+
+    int fd = mkstemp(fn);
+
+    CHK_CORE(fd >= 0, KLispErrFileNotFound); // FIXME: not very clear
+
+    if (fd < 0) {
+        InternalFalse(aEnvironment, RESULT);
+    } else {
+        close(fd);
+        RESULT = (LispAtom::New(aEnvironment,aEnvironment.HashTable().LookUpStringify(fn)->c_str()));
+    }
+}
+
 /// Implements the Yacas functions \c RuleBase and \c MacroRuleBase .
 /// The real work is done by LispEnvironment::DeclareRuleBase().
 static void InternalRuleBase(LispEnvironment& aEnvironment, LispInt aStackTop,
@@ -1505,11 +1527,10 @@ void LispFindFile(LispEnvironment& aEnvironment,LispInt aStackTop)
     LispString oper;
     InternalUnstringify(oper, orig);
 
-    LispChar filename[1024];//TODO FIXME
+    LispChar filename[PATH_MAX];//TODO FIXME
     InternalFindFile(oper.c_str(), aEnvironment.iInputDirectories,
                      filename);
-    LispString res(filename,1);
-    RESULT = (LispAtom::New(aEnvironment,aEnvironment.HashTable().LookUpStringify(res.c_str())->c_str()));
+    RESULT = (LispAtom::New(aEnvironment,aEnvironment.HashTable().LookUpStringify(filename)->c_str()));
 }
 
 void LispIsGeneric(LispEnvironment& aEnvironment,LispInt aStackTop)
@@ -1525,7 +1546,7 @@ void LispGenericTypeName(LispEnvironment& aEnvironment,LispInt aStackTop)
 
     CHK_ARG_CORE(evaluated->Generic(),1);
 
-    LispChar * name = evaluated->Generic()->TypeName();
+    const LispChar * name = evaluated->Generic()->TypeName();
     RESULT = (LispAtom::New(aEnvironment,name));
 }
 
